@@ -34,11 +34,16 @@ typedef void (*BluetoothClientSetupFunc) (BluetoothClient *client,
 					  const GError    *error,
 					  const char      *device_path);
 
-gboolean bluetooth_client_setup_device (BluetoothClient          *client,
-					const char               *device_path,
-					const char               *agent,
-					BluetoothClientSetupFunc  func,
-					gboolean                  pair);
+void bluetooth_client_setup_device (BluetoothClient          *client,
+				    const char               *path,
+				    gboolean                  pair,
+				    GCancellable             *cancellable,
+				    GAsyncReadyCallback       callback,
+				    gpointer                  user_data);
+gboolean bluetooth_client_setup_device_finish (BluetoothClient  *client,
+					       GAsyncResult     *res,
+					       char            **path,
+					       GError          **error);
 
 gboolean bluetooth_client_set_trusted(BluetoothClient *client,
 					const char *device, gboolean trusted);
@@ -49,6 +54,10 @@ GDBusProxy *bluetooth_client_get_device (BluetoothClient *client,
 void bluetooth_client_dump_device (GtkTreeModel *model,
 				   GtkTreeIter *iter);
 
+gboolean bluetooth_client_get_connectable(const char **uuids);
+
+GDBusProxy *_bluetooth_client_get_default_adapter (BluetoothClient *client);
+
 G_END_DECLS
 
 #endif /* __BLUETOOTH_CLIENT_PRIVATE_H */
